==> pdapi-1.20.4+1.0.1-sources.jar: ml/pluto7073/pdapi/addition/action/RestoreHungerAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2540;

public class RestoreHungerAction implements OnDrinkAction {

    private final int food, saturation;

    public RestoreHungerAction(int food, int saturation) {
        this.food = food;
        this.saturation = saturation;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        if (!(user instanceof class_1657 player)) return;
        player.method_7344().method_7585(food, saturation);
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.RESTORE_HUNGER;
    }

    public static class Serializer implements OnDrinkSerializer<RestoreHungerAction> {

        public static final Codec<RestoreHungerAction> CODEC = RecordCodecBuilder.create(instance ->
                instance.group(Codec.INT.fieldOf("food").forGetter(action -> action.food),
                        Codec.INT.fieldOf("saturation").forGetter(action -> action.saturation))
                        .apply(instance, RestoreHungerAction::new));

        @Override
        public Codec<RestoreHungerAction> codec() {
            return CODEC;
        }

        @Override
        public RestoreHungerAction fromNetwork(class_2540 buf) {
            int food = buf.readInt();
            int saturation = buf.readInt();
            return new RestoreHungerAction(food, saturation);
        }

        @Override
        public void toNetwork(class_2540 buf, RestoreHungerAction action) {
            buf.method_53002(action.food);
            buf.method_53002(action.saturation);
        }

    }

}

==> pdapi-1.20.6+2.0.2-sources.jar: ml/pluto7073/pdapi/addition/action/RestoreHungerAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2540;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public class RestoreHungerAction implements OnDrinkAction {

    private final int food, saturation;

    public RestoreHungerAction(int food, int saturation) {
        this.food = food;
        this.saturation = saturation;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        if (!(user instanceof class_1657 player)) return;
        player.method_7344().method_7585(food, saturation);
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.RESTORE_HUNGER;
    }

    public static class Serializer implements OnDrinkSerializer<RestoreHungerAction> {

        public static final MapCodec<RestoreHungerAction> CODEC = RecordCodecBuilder.mapCodec(instance ->
                instance.group(Codec.INT.fieldOf("food").forGetter(action -> action.food),
                        Codec.INT.fieldOf("saturation").forGetter(action -> action.saturation))
                        .apply(instance, RestoreHungerAction::new));
        public static final class_9139<class_9129, RestoreHungerAction> STREAM_CODEC =
                class_9139.method_56437(Serializer::toNetwork, Serializer::fromNetwork);

        @Override
        public MapCodec<RestoreHungerAction> codec() {
            return CODEC;
        }

        @Override
        public class_9139<class_9129, RestoreHungerAction> streamCodec() {
            return STREAM_CODEC;
        }

        public static RestoreHungerAction fromNetwork(class_2540 buf) {
            int food = buf.readInt();
            int saturation = buf.readInt();
            return new RestoreHungerAction(food, saturation);
        }

        public static void toNetwork(class_2540 buf, RestoreHungerAction action) {
            buf.method_53002(action.food);
            buf.method_53002(action.saturation);
        }

    }

}
